︠b753c81e-2550-4c16-99c0-cf0bc883fa28si︠
print "(A note to myself: Hidden code -- do not delete! --G.J.)"
# for internal use: Precompute x coordinate of left focus by geometric method
# x,z,cL,cR,rL,rR=var('x,z,cL,cR,rL,rR')
# print "ellipse:"
# (((x-cL)^2+z^2-(rL+rR)^2)-((x-(cL+cR)/2)^2+z^2-((cL-cR)/2)^2)).expand()
# print "hyperbola:"
# (((x-cL)^2+z^2-(rL-rR)^2)-((x-(cL+cR)/2)^2+z^2-((cL-cR)/2)^2)).expand()
##################################
### Define ellipse class
##################################
class Ellipse3d(object):
    """usage: Ellipse3d(slope,centerL,centerR)
    Calculates parameters for plotting an ellipse as a conic section.
    x-axis = axis of cone, vertex = (0,0,0)
    plane is parallel to y-axis
    slope = m defines generator of cone: x = m*z, y=0
    centers are x coordinates of centers of tangent sphere.
    Assumes centerL < centerR < 0 and m>0."""

    def __init__(self,m,cL,cR):
        self.m = m          # cone slope
        # sphere centers
        self.c_sphL = [cL,0,0]
        self.c_sphR = [cR,0,0]
        # sphere radii
        self.r_sphL = rL = abs(cL)/sqrt(1+m^2)
        self.r_sphR = rR = abs(cR)/sqrt(1+m^2)
        # centers of tangent circles
        self.c_cirL = [cL + rL/sqrt(1+m^2),0,0]
        self.c_cirR = [cR + rR/sqrt(1+m^2),0,0]
        # radii of tangent circles
        self.r_cirL = m*rL/sqrt(1+m^2)
        self.r_cirR = m*rR/sqrt(1+m^2)
        
        # points where plane is tangent to spheres (precomputed with the geometric method)
        # (xx,zz) is point where circle((cL,0),rL+rR) meets circle((cL+cR)/2,0),(cL-cR)/2)
        xx = (cL^2 - cL*cR - rL^2 - 2*rL*rR - rR^2)/(cL - cR)
        zz = sqrt((rL+rR)^2 - (cL-xx)^2)
        # left focus
        xL = cL + (xx-cL)*rL/(rL+rR) # x coordinate of left focus
        zL = zz*rL/(rL+rR)           # z coordinate of left focus
        self.focL_3d = [xL,0,zL]
        # right focus
        xR = cR - (xx-cL)*rR/(rL+rR) # x coordinate of right focus
        zR = -zz*rR/(rL+rR)          # z coordinate of right focus
        self.focR_3d = [xR,0,zR]
        # private parameters
        self.__a__ = a = (xL-xR)/(zL-zR)  # slope of ellipse plane
        self.__b__ = b = xR - a*zR        # x - intercept of ellipse plane
        
        # projections into ellipse plane
        self.__D__ = D = sqrt(a^2+1)
        self.focL_2d = [(-a*xL-zL)/D,0]
        self.focR_2d = [(-a*xR-zR)/D,0]
        

    def x_plane(self,z):
        """x = x_plane(z) is equation of ellipse plane"""
        a = self.__a__
        b = self.__b__
        return a*z + b

    def pt_3d(self,t):
        """(x,y,z)=pt(t) parametrizes the ellipse in space"""
        a = self.__a__
        b = self.__b__
        m = self.m
        rho = -b/(m+a*cos(t))
        return [-m*rho,rho*sin(t),rho*cos(t)]
    
    def pt_2d(self,t):
        """(x,y,z)=pt(t) parametrizes the ellipse in its plane"""
        a = self.__a__
        b = self.__b__
        D = self.__D__
        m = self.m
        rho = -b/(m+a*cos(t))
        return [(a*m*rho-rho*cos(t))/D,rho*sin(t)]
############################
### Define Hyperbola class
############################
class Hyperbola3d(object):
    """usage: Hyperbola3d(slope,centerL,centerR)
    Calculates parameters for plotting a hyperbola as a conic section.
    x-axis = axis of cone, vertex = (0,0,0)
    plane is parallel to y-axis
    slope = m defines generator of cone: z = m*x, y=0
    centers are x coordinates of centers of tangent sphere.
    Assumes centerL < 0 < centerR and m>0 and |centerL|>|centerR|."""

    def __init__(self,m,cL,cR):
        self.m = m           # cone slope
        # sphere centers
        self.c_sphL = [cL,0,0]
        self.c_sphR = [cR,0,0]
        # sphere radii
        self.r_sphL = rL = m*abs(cL)/sqrt(1+m^2)
        self.r_sphR = rR = m*abs(cR)/sqrt(1+m^2)
        # radii of tangent circles
        self.r_cirL = m*rL/sqrt(1+m^2)
        self.r_cirR = m*rR/sqrt(1+m^2)
        # centers of tangent circles
        self.c_cirL = [cL + rL/sqrt(1+m^2),0,0]
        self.c_cirR = [cR - rR/sqrt(1+m^2),0,0]
        # points where plane is tangent to spheres (precomputed with the geometric method)
        # (xx,zz) is point where circle((CL,0,0),rL+rR) meets circle((cL+cR)/2,0,0),(cL-cR)/2)
        xx = (cL^2 - cL*cR - rL^2 + 2*rL*rR - rR^2)/(cL - cR)
        zz = sqrt((rL-rR)^2 - (cL-xx)^2)
        # left focus
        xL = cL + (xx-cL)*rL/(rL-rR)  # x coordinate of left focus
        zL = zz*rL/(rL-rR)            # z coordinate of left focus
        self.focL_3d = [xL,0,zL]
        # right focus
        xR = cR + (xx-cL)*rR/(rL-rR)  # x coordinate of right focus
        zR = zz*rR/(rL-rR)            # z coordinate of right focus
        self.focR_3d = [xR,0,zR]
        # plus some private variables for hyperbola plane z = a*x+b
        self.__a__ = a = (zL-zR)/(xL-xR)   # slope of plane
        self.__b__ = b = zR - a*xR         # intercept of plane
        self.__D__ = D = sqrt(a^2+1)
        # projections into hyperbola plane
        self.focL_2d = [(xL+a*zL)/D,0]
        self.focR_2d = [(xR+a*zR)/D,0]
        # private variables used in parametrizing the hyperbola: (x-P)^2/A^2 + y^2/B^2 == 1
        Q = m^2-a^2
        P = a*b/Q
        A = m*b/Q
        B = m*b/sqrt(Q)
        self.__P__ = P
        self.__A__ = A
        self.__B__ = B

    def z_plane(self,x):
        """z = self.z_plane(x) is equation of plane"""
        a = self.__a__
        b = self.__b__
        return a*x + b

    def ptL_3d(self,t):
        """(x,y,z)=ptL_3d(t) parametrizes the left side of the hyperbola in space"""
        a = self.__a__
        b = self.__b__
        P = self.__P__
        A = self.__A__
        B = self.__B__
        x = -A*cosh(t)+P
        y = B*sinh(t)
        z = a*x+b
        return (x,y,z)

    def ptR_3d(self,t):
        """(x,y,z)=ptR_3d(t) parametrizes the right side of the hyperbola in space"""
        a = self.__a__
        b = self.__b__
        P = self.__P__
        A = self.__A__
        B = self.__B__
        x = A*cosh(t)+P
        y = B*sinh(t)
        z = a*x+b
        return (x,y,z)
    
    def ptL_2d(self,t):
        """(x,y,z)=ptL_3d(t) parametrizes the left side of the hyperbola in space"""
        a = self.__a__
        b = self.__b__
        P = self.__P__
        A = self.__A__
        B = self.__B__
        D = self.__D__
        x = -A*cosh(t)+P
        y = B*sinh(t)
        z = a*x+b
        return ( (x+a*z)/D,y)

    def ptR_2d(self,t):
        """(x,y,z)=ptR_3d(t) parametrizes the right side of the hyperbola in space"""
        a = self.__a__
        b = self.__b__
        P = self.__P__
        A = self.__A__
        B = self.__B__
        D = self.__D__
        x = A*cosh(t)+P
        y = B*sinh(t)
        z = a*x+b
        return ((x+a*z)/D,y)
###########################
## Defind Parabola class
###########################
class Parabola3d(object):
    """usage: Parabola3d(slope,center)
    Calculates parameters for plotting a parabola as a conic section.
    x-axis = axis of cone, vertex = (0,0,0)
    plane is parallel to y-axis
    slope = m defines generator of cone: x = m*z, y=0
    center is the x coordinate of center of tangent sphere."""

    def __init__(self,m,c):
        self.m = m                       # cone slope
        self.c_sph = [c,0,0]             # sphere center
        self.r_sph = abs(c)/sqrt(1+m^2)  # radius of tangent sphere
        self.r_cir = abs(c)*m/(1+m^2)    # radius of tangent circle
        x = c-c/(1+m^2)              # x coord of center of tangent circle center and directrix
        self.c_cir = [x,0,0]         # center of tangent circle
        xf = c+c/(1+m^2)                 # x-coordinate of focus
        zf = abs(c)*m/(1+m^2)            # z-coordinate of focus
        self.foc_3d = [xf,0,zf]         # focus
        # private variables                     
        self.__b__ = b = xf - m*zf           # parabola plane x-intercept
        self.__D__ = D = sqrt(1+m^2)
        self.__x_dir3d__ = x                 # x coordinate of directrix (3d)
        self.__z_dir3d__ = z = (x - b)/m     # z coordinate of directrix (3d)
        self.__x_dir2d__ = (m*x + z)/D       # x coordinate of directrix (2d)
        # focus (2d)
        self.foc_2d = [(m*xf + zf)/D,0]
 
    def x_plane(self,z):
        """x = self.x_plane(z) parametrizes the parabola plane"""
        m = self.m
        b = self.__b__
        return m*z + b

    def pt_3d(self,y):
        """(x,y,z) = self.par(y) parametrizes the parabola"""
        m = self.m
        b = self.__b__
        z = (m^2*y^2-b^2)/(2*m*b)
        x = m*z + b
        return (x,y,z)
    
    def dir_3d(self,y):
        """(x,y,z)=dir3d(y) parametrizes the directrix"""
        return [self.__x_dir3d__, y, self.__z_dir3d__]
    
    def pt_2d(self,y):
        m = self.m
        b = self.__b__
        D = self.__D__
        z = (m^2*y^2-b^2)/(2*m*b)
        x = m*z + b
        return [(m*x+z)/D,y]
    
    def dir_2d(self,y):
        return [self.__x_dir2d__,y]
    
#########################################
### Picture of angles determining type of conic
########################################
t=var('t')
angle_fig = line([(1,-.6),(0,0),(1,.6)]) #cone sides
angle_fig += line([(.4,-.6),(.7,.6)]) # plane
angle_fig += text("plane",(.57,.55),color="black")
angle_fig += line([(0,0),(1,0)], color="black") #axis
angle_fig += text("axis",(1.13,0), color="black")
angle_fig += parametric_plot((0.55+.12*cos(t),.12*sin(t)),(t,.1,1.2),linestyle="--", color="black") # beta
angle_fig += text("$\\beta$",(.69,.1), color="black")
angle_fig += parametric_plot((.2*cos(t),.2*sin(t)),(t,0,0.55),linestyle="--", color="black") # alpha
angle_fig += text("$\\alpha$", (.23,.07),color="black")
angle_fig += parametric_plot((1+0.03*cos(t), .6*sin(t)),(t,0,2*pi)) # cone base
angle_fig.save("angle_fig.png", aspect_ratio = 1, axes=False,figsize=4)
############################################
## 3d pictures of the conics
############################################
## ellipse ##
ell = Ellipse3d(2,-15,-5)
zmax_ell = 7
x,y,z,rho,t = var('x,y,z,rho,t')
cone_ell = parametric_plot3d((-ell.m*rho,rho*cos(t),rho*sin(t)),(rho,0,zmax_ell),(t,0,2*pi),opacity=0.3)
plane_ell = parametric_plot3d((ell.x_plane(z),y,z),(y,-zmax_ell,zmax_ell),(z,-zmax_ell,zmax_ell),color="blue",opacity=0.2)
ellipse = parametric_plot3d(ell.pt_3d(t), (t,0,2*pi),color='red',thickness=2)
conicSec_ell = plane_ell + cone_ell + ellipse
## parabola
par = Parabola3d(1.5,-10)
zmax_par=18
cone_par = parametric_plot3d((-par.m*rho,rho*cos(t),rho*sin(t)),(rho,0,zmax_par),(t,0,2*pi),opacity=0.3)
plane_par = parametric_plot3d((par.x_plane(z),y,z),(y,-zmax_par,zmax_par),(z,-11,11),color="blue",opacity=0.2)
parabola = parametric_plot3d(par.pt_3d(t),(t,-17,17),color="red",thickness=2)
conicSec_par = plane_par + cone_par + parabola
## hyperbola
hyp = Hyperbola3d(.9,-15,10)
xmax_hyp = 20
cone_hyp = parametric_plot3d((rho,hyp.m*rho*cos(t),hyp.m*rho*sin(t)),(rho,-xmax_hyp,xmax_hyp),(t,0,2*pi),opacity=0.3)
plane_hyp = parametric_plot3d((x,y,hyp.z_plane(x)),(x,-xmax_hyp,xmax_hyp),(y,-xmax_hyp,xmax_hyp),color="blue",opacity=0.2)
hyperbola = parametric_plot3d(hyp.ptL_3d(t), (t,-1.35,1.35),color='red',thickness=2)+parametric_plot3d(hyp.ptR_3d(t), (t,-1.45,1.45),color='red',thickness=2)
conicSec_hyp = cone_hyp + plane_hyp + hyperbola
############################################
## make and save animations
############################################
## plane projection for ellipse ##
t=var('t')
plane_ell_foci = point([ell.focL_2d,ell.focR_2d])
plane_ell = parametric_plot(ell.pt_2d(t),(t,0,2*pi),color="red")
def ell_focLength_frame(t):
    frame = line([ell.focL_2d, ell.pt_2d(t)], axes=False, ymin=-4.5, color="green")
    frame += line([ell.focR_2d, ell.pt_2d(t)], color="purple")
    frame += plane_ell + plane_ell_foci
    return frame
ell_frames = [ell_focLength_frame(t) for t in sxrange(pi/4,9*pi/4,pi/18)]
ell_animated=animate(ell_frames)
ell_animated.gif(savefile="ellipse_animation.gif")
## plane projection for hyperbola ##
t=var('t')
plane_hyp_foci = point([hyp.focL_2d,hyp.focR_2d])
plane_hyp2d = parametric_plot(hyp.ptL_2d(t),(t,-1.4,1.4),color="red") + parametric_plot(hyp.ptR_2d(t),(t,-1.4,1.4),color="red")
def hyp_focLength_frame_L(t):
    frame = line([hyp.focL_2d, hyp.ptL_2d(t)], axes=False, ymin=-18, color="green")
    frame += line([hyp.focR_2d, hyp.ptL_2d(t)], color="purple")
    frame += plane_hyp2d + plane_hyp_foci
    return frame
def hyp_focLength_frame_R(t):
    frame = line([hyp.focL_2d, hyp.ptR_2d(t)], axes=False, ymin=-18, color="purple")
    frame += line([hyp.focR_2d, hyp.ptR_2d(t)], color="green")
    frame += plane_hyp2d + plane_hyp_foci
    return frame
hyp_frames_L = [hyp_focLength_frame_L(t) for t in sxrange(-1.4, 1.5, 0.2)]
hyp_frames_R = [hyp_focLength_frame_R(t) for t in sxrange(1.4,-1.5, -0.2)]
hyp_animated = animate(hyp_frames_L + hyp_frames_R)
hyp_animated.gif(savefile="hyperbola_animation.gif")
## plane projection for parabola ##
t=var('t')
plane_par_focus = point(par.foc_2d)
plane_par_directrix = line([par.dir_2d(-17),par.dir_2d(17)],color="green")
plane_par = parametric_plot(par.pt_2d(t),(t,-17,17),color = "red")
def par_focLength_frame(t):
    frame = line([par.foc_2d, par.pt_2d(t)], axes=False, xmin=-30, ymin=-19, color="purple")
    frame += line([par.dir_2d(t), par.pt_2d(t)], color="green")
    frame += plane_par + plane_par_focus + plane_par_directrix
    return frame
par_frames = [par_focLength_frame(t) for t in sxrange(-16,17,2)]
par_animated = animate(par_frames)
par_animated.gif(savefile="parabola_animation.gif")
############################################
## Run tests (do the classes work?)
## All tests passed so output is suppressed
############################################
# test Ellipse3d
#z=var('z')
#ell = Ellipse3d(2,-15,-5)
#zmax = 10
#cone_section = line([(-ell.m*zmax,zmax),(0,0),(-ell.m*zmax,-zmax)])
#sphere_centers = point([ell.c_sphL[:2], ell.c_sphR[:2]])
#sphere_sections = circle(ell.c_sphL[:2], ell.r_sphL) + circle(ell.c_sphR[:2], ell.r_sphR)
#tan_points = point([(ell.c_cirL[0],ell.r_cirL), (ell.c_cirR[0],ell.r_cirR)])
#foci = point([(ell.focL_3d[:3:2]), (ell.focR_3d[:3:2])])
#tanLine = parametric_plot((ell.x_plane(z),z),(z,-zmax,zmax))
#cone_section + sphere_centers + sphere_sections + tan_points + foci + tanLine

# test Hyperbola3d
# hyp=Hyperbola3d(.9,-15,10)
# xmax = 20
# cone_section = line([(-xmax,-xmax*hyp.m),(xmax,xmax*hyp.m)])+line([(-xmax,xmax*hyp.m),(xmax,-xmax*hyp.m)])
# sphere_centers = point([hyp.c_sphL[:2], hyp.c_sphR[:2]])
# sphere_sections = circle(hyp.c_sphL[:2], hyp.r_sphL) + circle(hyp.c_sphR[:2], hyp.r_sphR)
# tan_points = point([(hyp.c_cirL[0],hyp.r_cirL), (hyp.c_cirR[0],hyp.r_cirR)])
# foci = point([(hyp.focL_3d[:3:2]), (hyp.focR_3d[:3:2])])
# plane_section = parametric_plot((x,hyp.z_plane(x)),(x,-xmax,xmax))
#cone_section + sphere_centers + sphere_sections + tan_points + foci + plane_section

# test parabola
# par = Parabola3d(1.5,-10)
# zmax = 13
# cone_section = line([(-par.m*zmax,zmax),(0,0),(-par.m*zmax,-zmax)])
# sphere_center = point(par.c_sph[:2])
# sphere_section = circle(par.c_sph[:2], par.r_sph)
# tan_point = point((par.c_cir[0],par.r_cir))
# focus = point(par.foc_3d[:3:2])
# plane_section = parametric_plot((par.x_plane(z),z),(z,-1,12))
#cone_section + sphere_center + sphere_section + tan_point + focus + plane_section

︡d8d4f2dc-b907-42c3-b4e9-fa5ff0b191a2︡{"stdout":"(A note to myself: Hidden code -- do not delete! --G.J.)\n"}︡{"done":true}︡
︠43f917f2-27dd-4001-86dc-73d17d6f90bbi︠
%md
**INSTRUCTIONS:** click the "Open in Cocalc" link on the upper right to make the 3d graphics display.  You may have to refresh your browser once or twice to load everything.  Keep scrolling down until you reach the last frame, which says "The End."

<h1>Conic Sections and Dandelin's Spheres</h1>   

A **conic section**, or "**conic**", is a curve obtained by intersecting a plane with a right circular cone.  Let $\alpha$ be the angle between the cone's axis and any line that lies in the cone (a "generator"), and let $\beta$ be the angle between the cone's axis and the plane.  (The plane is viewed "edge-on" in the figure.)

<image src="angle_fig.png"></image>

The shape of the conic depends on these angles, and whether or not the plane intersects the vertex of the cone.
    
If the plane intersects the vertex the conic is "singular"; it is an isolated point if $\alpha < \beta$, two intersecting lines if $\alpha > \beta$, or one line "counted twice" if $\alpha = \beta$.  

If the plane does not intersect the vertex the conic is "smooth".  A smooth conic is 

    
1. an **ellipse** if $\alpha < \beta$, 
    
2. a **hyperbola** if $\alpha > \beta$, or 

3. a **parabola** if $\alpha = \beta$. 

I'll concentrate on the smooth conics.  Below are some pictures.  To rotate a picture select it then move the mouse holding down the left mouse button.  Enlarge the picture with the mouse wheel on a PC, or "shrink or enlarge" finger motions on a mac.  **All the 3d pictures work better if one rotates and enlarges them.** 
︡c86ea686-6507-41d4-8a34-c88fe0c5b033︡{"done":true,"md":"**INSTRUCTIONS:** click the \"Open in Cocalc\" link on the upper right to make the 3d graphics display.  You may have to refresh your browser once or twice to load everything.  Keep scrolling down until you reach the last frame, which says \"The End.\"\n\n<h1>Conic Sections and Dandelin's Spheres</h1>   \n\nA **conic section**, or \"**conic**\", is a curve obtained by intersecting a plane with a right circular cone.  Let $\\alpha$ be the angle between the cone's axis and any line that lies in the cone (a \"generator\"), and let $\\beta$ be the angle between the cone's axis and the plane.  (The plane is viewed \"edge-on\" in the figure.)\n\n<image src=\"angle_fig.png\"></image>\n\nThe shape of the conic depends on these angles, and whether or not the plane intersects the vertex of the cone.\n    \nIf the plane intersects the vertex the conic is \"singular\"; it is an isolated point if $\\alpha < \\beta$, two intersecting lines if $\\alpha > \\beta$, or one line \"counted twice\" if $\\alpha = \\beta$.  \n\nIf the plane does not intersect the vertex the conic is \"smooth\".  A smooth conic is \n\n    \n1. an **ellipse** if $\\alpha < \\beta$, \n    \n2. a **hyperbola** if $\\alpha > \\beta$, or \n\n3. a **parabola** if $\\alpha = \\beta$. \n\nI'll concentrate on the smooth conics.  Below are some pictures.  To rotate a picture select it then move the mouse holding down the left mouse button.  Enlarge the picture with the mouse wheel on a PC, or \"shrink or enlarge\" finger motions on a mac.  **All the 3d pictures work better if one rotates and enlarges them.**"}
︠7facaa4d-e6f1-4da5-9d8e-1c3349216856si︠
print "Ellipse"
show(conicSec_ell.rotateX(.02*pi).rotateZ(-.24*pi),frame=False)
︡6f2c4b19-c567-4f66-ad62-2bbd75a1cad0︡{"stdout":"Ellipse\n"}︡{"file":{"filename":"4a84520c-98c3-4031-b14c-b4c10000e03b.sage3d","uuid":"4a84520c-98c3-4031-b14c-b4c10000e03b"}}︡{"done":true}︡
︠0592e139-783f-49d5-86ec-1196147fde75si︠
print "Parabola"
show(conicSec_par.rotateX(pi).rotateX(.02*pi).rotateZ(-.26*pi),frame=False)
︡02564ee4-2a5b-401c-9c18-85ee568bb74b︡{"stdout":"Parabola\n"}︡{"file":{"filename":"bd7c458b-19fa-475e-b50c-cea0856e4377.sage3d","uuid":"bd7c458b-19fa-475e-b50c-cea0856e4377"}}︡{"done":true}︡
︠5f7ef51e-f78b-4862-ab63-d38383edec5dsi︠
print "Hyperbola"
show(conicSec_hyp.rotateX(.05*pi).rotateZ(-.1*pi),frame=False)
︡8b7a4d49-1171-4a90-8eb2-bed20655c9c3︡{"stdout":"Hyperbola\n"}︡{"file":{"filename":"bcae9668-90cb-4380-beca-61e770024d59.sage3d","uuid":"bcae9668-90cb-4380-beca-61e770024d59"}}︡{"done":true}︡
︠81164519-d6fb-440a-a8bb-a0f607fa5913i︠
%md
<h3>Focus and Directrix</h3>

The ellipse has two special points called **foci**.  Dandelin constructed them by placing spheres inside the cone so that each sphere is tangent to the plane at a point, and tangent to the cone along a circle that is perpendicular to the axis of the cone.  (To see that this always possible, put very small spheres inside the cone then inflate them until they are in the right position.)  The foci are the points where the spheres touch the plane.      
︡54fe623d-fce9-4310-acc0-974232c3c24d︡{"done":true,"md":"<h3>Focus and Directrix</h3>\n\nThe ellipse has two special points called **foci**.  Dandelin constructed them by placing spheres inside the cone so that each sphere is tangent to the plane at a point, and tangent to the cone along a circle that is perpendicular to the axis of the cone.  (To see that this always possible, put very small spheres inside the cone then inflate them until they are in the right position.)  The foci are the points where the spheres touch the plane."}
︠1abc44f5-7c7e-4225-b08c-dc9e9b90ea59i︠
ell = Ellipse3d(2,-15,-5)
zmax_ell = 7
x,y,z,rho,t = var('x,y,z,rho,t')
cone_ell = parametric_plot3d((-ell.m*rho,rho*cos(t),rho*sin(t)),(rho,0,zmax_ell),(t,0,2*pi),opacity=0.3)
plane_ell = parametric_plot3d((ell.x_plane(z),y,z),(y,-zmax_ell,zmax_ell),(z,-zmax_ell,zmax_ell),color="blue",opacity=0.2)
ellipse = parametric_plot3d(ell.pt_3d(t), (t,0,2*pi),color='red',thickness=2)
foci_ell = sphere(ell.focL_3d, 0.2, color="red") + sphere(ell.focR_3d, 0.2, color="red")
spheres_ell = sphere(ell.c_sphL, ell.r_sphL, color="blue", opacity=.5) + sphere(ell.c_sphR, ell.r_sphR, color="blue", opacity=.5)
#conicSec_ell = plane_ell + cone_ell + ellipse
print "Foci of ellipse"
#show(conicSec_ell.rotateX(.02*pi).rotateZ(-.24*pi),frame=False)
show((foci_ell + spheres_ell + cone_ell + plane_ell + ellipse).rotateX(.2).rotateZ(-.8), frame = False)
︡cd3068fb-bedc-42ba-b137-d523db896d66︡{"stdout":"Foci of ellipse\n"}︡{"file":{"filename":"1449484b-0539-423b-87ec-371b731b8a03.sage3d","uuid":"1449484b-0539-423b-87ec-371b731b8a03"}}︡{"done":true}︡
︠9e37ecff-2bf4-470d-bc2c-1ad1841976bfi︠
%md
The foci of the ellipse have a special distance-to-foci property:

*The sum of the distances from the foci to the point $P$ is the same for every point $P$ on the ellipse.*  

In the figure the purple length plus the green length is constant.

<image src="ellipse_animation.gif"></image>
︡2463b730-9481-4f73-ab7c-6a2a780826da︡{"done":true,"md":"The foci of the ellipse have a special distance-to-foci property:\n\n*The sum of the distances from the foci to the point $P$ is the same for every point $P$ on the ellipse.*  \n\nIn the figure the purple length plus the green length is constant.\n\n<image src=\"ellipse_animation.gif\"></image>"}
︠b3efb8c9-d24c-40ab-b988-0b003ad11a60i︠
%md
The hyperbola also has two foci, constructed in a similar way using Dandelin's spheres.
︡c290f9bb-d73a-4986-8419-7a6ba0f10d82︡{"done":true,"md":"The hyperbola also has two foci, constructed in a similar way using Dandelin's spheres."}
︠312eee8e-5acc-4418-a81a-f116f45e3d64si︠
t=var('t')
hyp = Hyperbola3d(.9,-15,10)
xmax_hyp = 20
cone_hyp = parametric_plot3d((rho,hyp.m*rho*cos(t),hyp.m*rho*sin(t)),(rho,-xmax_hyp,xmax_hyp),(t,0,2*pi),opacity=0.2)
plane_hyp = parametric_plot3d((x,y,hyp.z_plane(x)),(x,-xmax_hyp,xmax_hyp),(y,-xmax_hyp,xmax_hyp),color="blue",opacity=0.2)
hyperbola = parametric_plot3d(hyp.ptL_3d(t), (t,-1.35,1.35),color='red',thickness=2)+parametric_plot3d(hyp.ptR_3d(t), (t,-1.45,1.45),color='red',thickness=2)
foci_hyp = sphere(hyp.focL_3d, 0.5, color="red") + sphere(hyp.focR_3d, 0.5, color="red")
spheres_hyp = sphere(hyp.c_sphL, hyp.r_sphL, color="blue", opacity=.5) + sphere(hyp.c_sphR, hyp.r_sphR, color="blue", opacity=.5)
print "Foci of hyperbola"
show((spheres_hyp + foci_hyp + cone_hyp + plane_hyp + hyperbola).rotateX(.05*pi).rotateZ(-.1*pi), frame = False)
︡8b683ab4-bb12-45ff-b8ea-a238cce889e1︡{"stdout":"Foci of hyperbola\n"}︡{"file":{"filename":"c817b3fa-bf02-4375-9a4f-5adb1cac8d97.sage3d","uuid":"c817b3fa-bf02-4375-9a4f-5adb1cac8d97"}}︡{"done":true}︡
︠1e7dca17-b4b5-480f-bb5c-1042f7e5e642i︠
%md
The foci of the hyperbola have a special distance-to-foci property:

*The difference of the distances from the foci to the point $P$ is the same for every point $P$ on the hyperbola.*  

In the figure, the purple length minus the green length is constant.

<image src="hyperbola_animation.gif"></image>
︡f802a3e7-88ba-42d9-9dec-8b54427b5c5a︡{"done":true,"md":"The foci of the hyperbola have a special distance-to-foci property:\n\n*The difference of the distances from the foci to the point $P$ is the same for every point $P$ on the hyperbola.*  \n\nIn the figure, the purple length minus the green length is constant\n\n<image src=\"hyperbola_animation.gif\"></image>"}
︠fba767a4-02f7-4286-9a9f-8b2985803a66i︠
%md
The parabola has one special point, its **focus**, plus a **directrix**, which is a special line.  As before, Dandelin constructed them by placing a sphere inside the cone, tangent to both the plane and the cone.  The sphere is tangent to the plane at the focus and tangent to the cone along a circle.  This circle lies in a plane that is perpendicular to the axis of the cone -- the green plane in the figure.  The intersection of this plane with the plane containing the parabola is the directrix.  
︡9a8827d2-1c75-42e2-be0f-45913577710b︡{"done":true,"md":"The parabola has one special point, its **focus**, plus a **directrix**, which is a special line.  As before, Dandelin constructed them by placing a sphere inside the cone, tangent to both the plane and the cone.  The sphere is tangent to the plane at the focus and tangent to the cone along a circle.  This circle lies in a plane that is perpendicular to the axis of the cone -- the green plane in the figure.  The intersection of this plane with the plane containing the parabola is the directrix."}
︠9f93e0c9-4b1f-4993-ba91-0818c7d349d8si︠
t=var('t')
par = Parabola3d(1.5,-10)
zmax_par=13
cone_par = parametric_plot3d((-par.m*rho,rho*cos(t),rho*sin(t)),(rho,0,zmax_par),(t,0,2*pi),opacity=0.3)
plane_par = parametric_plot3d((par.x_plane(z),y,z),(y,-zmax_par,zmax_par),(z,-2,11),color="blue",opacity=0.2)
sphere_par = sphere(par.c_sph, par.r_sph, opacity=0.3)
focus_par = sphere(par.foc_3d,.3, color="red")
parabola = parametric_plot3d(par.pt_3d(t),(t,-13,13),color="red",thickness=2)
circle_par = parametric_plot3d((par.c_cir[0], par.r_cir*cos(t),par.r_cir*sin(t)),(t,0,2*pi), color="green", thickness=2)
directrix = line([par.dir_3d(-13),par.dir_3d(13)],color="green",thickness=2)
directrix_plane = parametric_plot((par.c_cir[0],y,z),(y,-13,13),(z,-10,11),opacity=0.2,color="green")
dandelin_par = sphere_par + plane_par + cone_par + circle_par + focus_par + parabola + directrix + directrix_plane
show(dandelin_par.rotateX(0.22).rotateZ(-0.95),frame=False)
︡9b7c9839-a815-40ab-a784-baaf079bb286︡{"file":{"filename":"0621f3d4-f653-4b20-a91d-e6cba9cadb7b.sage3d","uuid":"0621f3d4-f653-4b20-a91d-e6cba9cadb7b"}}︡{"done":true}︡
︠b0ed7e3f-64fb-457c-beac-7099449033edi︠
%md
The parabola's focus and directrix have a distance-to-focus property 

*The distance from the focus to $P$ equals the distance from $P$ to the directrix, for every point $P$ on the parabola.*

In the figure the purple length equals the green length.  Of course the distance to the directrix is measured along a perpendicular to the directrix.

<image src="parabola_animation.gif"></image>
︡fb5754af-041e-41d0-84a4-36b6bde7d279︡{"done":true,"md":"The parabola's focus and directrix have a distance-to-focus property \n\n*The distance from the focus to $P$ equals the distance from $P$ to the directrix, for every point $P$ on the parabola.*\n\nIn the figure the purple length equals the green length.  Of course the distance to the directrix is measured along a perpendicular to the directrix.\n\n<image src=\"parabola_animation.gif\"></image>"}
︠087e304f-2035-48cf-bdb2-61fd5d7212a9i︠
%md
The ancients knew these distance-to-foci properties and an easy corollary: 

<h3>Corollary. Tangent lines and Angle bisectors: 

Conic-section-shaped mirrors reflect light (sound, radio waves, ...) in a special way.</h3>
︡796a7a1a-d323-40cc-a62c-2eaba0fbab66︡{"done":true,"md":"The ancients knew these distance-to-foci properties and an easy corollary: \n\n<h3>Corollary. Tangent lines and Angle bisectors: \n\nConic-section-shaped mirrors reflect light (sound, radio waves, ...) in a special way.</h3>"}
︠0d8456e2-740e-4162-b106-f311c9d07a19i︠
%md
Ellipse: light (black line) leaving one focus reflects into the other focus.
︡2ab332ab-1eb4-4cba-a108-50e155e3ef07︡{"done":true,"md":"Ellipse: light (black line) leaving one focus reflects into the other focus."}
︠e2879a26-dc47-4a28-9a5f-56b22fea35f4si︠
t_ell = 1
ell_refl = line([ell.focL_2d, ell.pt_2d(t_ell),ell.focR_2d], axes=False, ymin=-4.5, color="black")
ell_refl + plane_ell + plane_ell_foci
︡ceb45438-8918-490c-9806-40cbef966138︡{"file":{"filename":"/home/user/.sage/temp/project-b3d1725f-1279-45c2-88cc-f7f99fcc7faa/8108/tmp_JO5GRY.svg","show":true,"text":null,"uuid":"90c2add5-72fb-435f-9a6d-455b6ca67a19"},"once":false}︡{"done":true}︡
︠9fefa1f9-7fb9-4b50-afb3-3179a0804257i︠
%md
Hyperbola:  light (black line) traveling toward one focus reflects toward the other focus.
︡aca6e9d8-8a92-475d-ba45-08a6f623c7fe︡{"done":true,"md":"Hyperbola:  light (black line) traveling toward one focus reflects toward the other focus."}
︠534f042e-11a8-432f-a53c-dea920028efcsi︠
t_hyp = 0.9
dashedLine_hyp = line([hyp.focL_2d,hyp.ptL_2d(t_hyp)], linestyle="--", color="black")
v = vector(hyp.ptL_2d(t_hyp))
w = vector(hyp.focL_2d)
lightLine_hyp = line([(2*(v-w)+w).coefficients(), hyp.ptL_2d(t_hyp), hyp.focR_2d], color="black")
show(dashedLine_hyp + lightLine_hyp + plane_hyp2d + plane_hyp_foci , axes=False)
︡99112a74-e567-40d1-b234-5e9f483cda85︡{"file":{"filename":"/home/user/.sage/temp/project-b3d1725f-1279-45c2-88cc-f7f99fcc7faa/8108/tmp_V1BB9m.svg","show":true,"text":null,"uuid":"73b2e621-1b85-4ca1-b168-a4ebab4c1434"},"once":false}︡{"done":true}︡
︠147a20c5-2921-4756-8d08-55f0930a5d7ci︠
%md
Parabola:  light (black line) perpendicular to the directrix (green line) reflects into the focus
︡e3813719-af6b-4f41-b936-2032ccacb777︡{"done":true,"md":"Parabola:  light (black line) perpendicular to the directrix (green line) reflects into the focus"}
︠5b43ab66-a99d-4030-91c8-d684ad06764csi︠
ylev = 10
lightline_par = line([(-25,ylev), par.pt_2d(ylev), par.foc_2d],color="black")
dashedLine_par = line([par.pt_2d(ylev), par.dir_2d(ylev)],color="black",linestyle="--")
show(lightline_par + dashedLine_par + plane_par + plane_par_focus + plane_par_directrix, axes=False)
︡7a4dfba6-e85d-46c4-b1c7-80be6183e5d3︡{"file":{"filename":"/home/user/.sage/temp/project-b3d1725f-1279-45c2-88cc-f7f99fcc7faa/8108/tmp_djlgb_.svg","show":true,"text":null,"uuid":"f6635615-3a82-4e03-901c-395560954009"},"once":false}︡{"done":true}︡
︠a93f392b-cff3-4ba5-a9d4-89631f6599f7i︠
%md
The reflection properties follow immediately from the fact that the tangent lines (blue) bisect the obvious angles in the following figures.
︡8d4ee9b6-f332-420e-8a5c-f159a29c7097︡{"done":true,"md":"The reflection properties follow immediately from the fact that the tangent lines (blue) bisect the obvious angles in the following figures."}
︠437d9136-bf9b-40f5-9c75-29711a667766si︠
t=var('t')
t_ell = 1
# parametrize the tangent line
vp = vector(ell.pt_2d(t_ell))
wL = vector(ell.focL_2d)
wR = vector(ell.focR_2d)
DL = (vp-wL).norm()
DR = (vp-wR).norm()
zp = wR+(vp-wR)*(DL+DR)/DR  # far point
mid = wL + (zp-wL)/2
def tanLine_ell_pt(t):
    return (mid + t*(vp-mid)).coefficients()
extendedLine = line([zp.coefficients(), ell.focR_2d], color="black")
tanLine_ell = parametric_plot(tanLine_ell_pt(t), (t,-0.75,2.75))
leftFork_ell = line([ell.focL_2d, ell.pt_2d(t_ell)], color="black")
show(extendedLine + tanLine_ell + leftFork_ell + plane_ell + plane_ell_foci, axes=False)

︡2c0f60eb-2635-4bfa-872b-7a76c890e57e︡{"file":{"filename":"/home/user/.sage/temp/project-b3d1725f-1279-45c2-88cc-f7f99fcc7faa/8108/tmp__jzAUg.svg","show":true,"text":null,"uuid":"a2d1fd74-40df-4773-a222-7543549e02cb"},"once":false}︡{"done":true}︡
︠df3770f9-5227-4f67-a8e9-ccb99f3fc218si︠
t=var('t')
t_hyp=0.9
vp = vector(hyp.ptL_2d(t_hyp))
wL = vector(hyp.focL_2d)
wR = vector(hyp.focR_2d)
DL = (vp - wL).norm()
DR = (wR - vp).norm()
zp = vp + (wR - vp)*DL/DR
mid = (zp + wL)/2
def tanLine_hyp_pt(t):
    return (mid + t*(vp - mid)).coefficients()
tanLine_hyp = parametric_plot(tanLine_hyp_pt(t), (t,-.7,2.5))
right_fork_hyp = line([hyp.ptL_2d(t_hyp),hyp.focL_2d], color="black")
lightline_hyp = line([(2*(vp-wL)+wL).coefficients(), hyp.ptL_2d(t_hyp), hyp.focR_2d], color="black")
show(lightline_hyp + right_fork_hyp + plane_hyp2d + plane_hyp_foci + tanLine_hyp, axes=False)
︡d5ea044c-1e61-4f50-9d5d-8caae5465919︡{"file":{"filename":"/home/user/.sage/temp/project-b3d1725f-1279-45c2-88cc-f7f99fcc7faa/8108/tmp_8anD6g.svg","show":true,"text":null,"uuid":"5ebfa8d9-2afc-4a79-ab82-b1f6f331ad5c"},"once":false}
︠a877dd20-d3d7-4580-bc15-b5b99fce8a39si︠
ylev = 10
lightline_par = line([(-25,ylev),par.pt_2d(ylev),par.foc_2d],color="black")
rightFork_par = line([par.pt_2d(ylev),par.dir_2d(ylev)])
vp = vector(par.pt_2d(ylev))
mid = (vector(par.foc_2d)+vector(par.dir_2d(ylev)))/2
def tanLine_par_pt(t):
    return (mid + t*(vp - mid)).coefficients()
tanLine_par = parametric_plot(tanLine_par_pt(t),(t,-.4,2.4))
show(lightline_par + rightFork_par + plane_par + plane_par_focus + plane_par_directrix + tanLine_par, axes=False)
︡bd20c940-7cac-4887-9a47-fd2f95a4d7b9︡{"file":{"filename":"/home/user/.sage/temp/project-b3d1725f-1279-45c2-88cc-f7f99fcc7faa/8108/tmp_TNssIt.svg","show":true,"text":null,"uuid":"3b33ff7c-2b4a-430c-a410-d5d7f467a4f1"},"once":false}︡{"done":true}︡
︠719aed5c-1e2f-4439-83ed-0c3cc6e2692ci︠
%md
<h3>Proof that the angle bisector is tangent to the ellipse</h3>
<p>The proof is based on the distance-to-focus property of the ellipse, which will be proved below.  The proofs for the other conics are similar.</p>

<p>It's enough to show that the angle bisector (blue line) intersects the ellipse only at one point, $P$.</p>

<p>Let $Q\neq P$ be any other point on the blue line. Extend the segment $\overline{PF_2}$ to $\overline{EF_2}$ so the lengths of the green segments $EF_2 = PF_1$ are equal and $E,P,F_2$ are collinear.  The blue line bisects $\angle EPF_1$ so triangles $\Delta EPQ \cong \Delta F_1PQ$ are congruent (side-angle-side). $Q$ cannot be on the ellipse because the sum of the distances</p>
    $$ F_1Q + QF_2 = F_2Q + QE > F_2E = F_1P + PE = F_1P + PF_2.$$
<p>are not equal.</p>



︡d8eee883-d0cc-4583-845e-3860d03a8338︡{"done":true,"md":"<h3>Proof that the angle bisector is tangent to the ellipse</h3>\n<p>The proof is based on the distance-to-focus property of the ellipse, which will be proved below.  The proofs for the other conics are similar.</p>\n\n<p>It's enough to show that the angle bisector (blue line) intersects the ellipse only at one point, $P$.</p>\n\n<p>Let $Q\\neq P$ be any other point on the blue line. Extend the segment $\\overline{PF_2}$ to $\\overline{EF_2}$ so the lengths of the green segments $EF_2 = PF_1$ are equal and $E,P,F_2$ are collinear.  The blue line bisects $\\angle EPF_1$ so triangles $\\Delta EPQ \\cong \\Delta F_1PQ$ are congruent (side-angle-side). $Q$ cannot be on the ellipse because the sum of the distances</p>\n    $$ F_1Q + QF_2 = F_2Q + QE > F_2E = F_1P + PE = F_1P + PF_2.$$\n<p>are not equal.</p>"}
︠cca52d78-dc51-4195-88da-9059561c2666si︠
t=var('t')
t_ell = 1
# parametrize the tangent line
vp = vector(ell.pt_2d(t_ell))
wL = vector(ell.focL_2d)
wR = vector(ell.focR_2d)
DL = (vp-wL).norm()
DR = (vp-wR).norm()
zp = wR+(vp-wR)*(DL+DR)/DR  # far point
mid = wL + (zp-wL)/2
def tanLine_ell_pt(t):
    return (mid + t*(vp-mid)).coefficients()
extendedLine = line([zp.coefficients(), ell.pt_2d(t_ell),ell.focL_2d], color="green")
tanLine_ell = parametric_plot(tanLine_ell_pt(t), (t,-0.6,3.6))
rightFork_ell = line([ell.focR_2d, ell.pt_2d(t_ell)], color="purple")
dashedLine_ell = line([zp.coefficients(),tanLine_ell_pt(2.6),ell.focL_2d], linestyle="--", color = "green")
dashedFork_ell = line([tanLine_ell_pt(2.6),ell.focR_2d], linestyle="--", color="purple")
f1_label=text("$F_1$",(-6.8,-.5))
f2_label = text("$F_2$",(-2.1,-.5))
p_label = text("$P$",(-6,4))
e_label = text("$E$",(-8.9,6.2))
q_label = text("$Q$",(-3.3,4.8))
gr_Proof_ell = extendedLine + tanLine_ell + rightFork_ell + dashedLine_ell
gr_Proof_ell += plane_ell + plane_ell_foci + dashedFork_ell 
gr_Proof_ell += f1_label + f2_label + p_label + e_label + q_label
show(gr_Proof_ell, axes=False)
︡f1ac6bb4-a55f-45ca-857e-cc5a78dc0190︡{"file":{"filename":"/home/user/.sage/temp/project-b3d1725f-1279-45c2-88cc-f7f99fcc7faa/8108/tmp_PYUysi.svg","show":true,"text":null,"uuid":"ced71079-4481-4c5b-bce8-92dab51dbea2"},"once":false}︡{"done":true}︡
︠57afe3fb-89d4-450e-b88e-623b77a9827ci︠
%md
Finally ...
<h3>Dandelin's lovely proof of the Distance to Foci properties of conics.<h3>
︡079587f5-5ff1-4d62-841d-394d900d1338︡{"done":true,"md":"Finally ...\n<h3>Dandelin's lovely proof of the Distance to Foci properties of conics.<h3>"}
︠71a7aac8-e227-4d9d-b05b-799c1d32e19bi︠
%md 
<p>Here is our hero, Germinal Pierre Dandelin (1794-1847), Belgian soldier and professor of engineering.</p>
<p><image src="https://upload.wikimedia.org/wikipedia/commons/thumb/c/c4/Dandelin.jpg/220px-Dandelin.jpg"></image></p>

︡54fa3d9c-c429-410f-909e-230ff0936691︡{"done":true,"md":"<p>Here is our hero, Germinal Pierre Dandelin (1794-1847), Belgian soldier and professor of engineering.</p>\n<p><image src=\"https://upload.wikimedia.org/wikipedia/commons/thumb/c/c4/Dandelin.jpg/220px-Dandelin.jpg\"></image></p>"}
︠1f2d3c2e-dcc1-4458-80c8-9035cca7fd75i︠
%md
<p>His proof uses a simple property of circles and tangent lines.</p>

<p> If $\overline{PA}$ and $\overline{PB}$ are tangent to a circle at $A$ and $B$ then the lengths</p>
    $$PA = PB$$
<p>are equal.</p>

︡c2e13e90-ed3f-4311-b32c-a0ab99b30737︡{"done":true,"md":"<p>His proof uses a simple property of circles and tangent lines.</p>\n\n<p> If $\\overline{PA}$ and $\\overline{PB}$ are tangent to a circle at $A$ and $B$ then the lengths</p>\n    $$PA = PB$$\n<p>are equal.</p>"}
︠79b61cb1-7c89-4436-99c8-02c2fda6b987i︠
x0=5; r=2
circ = circle((0,0),r)
lin = line( [(r^2/x0, r*sqrt(1-r^2/x0^2)),(x0,0),(r^2/x0, -r*sqrt(1-r^2/x0^2))], color="red")
p = point((x0,0),color="red", size=50)
up = point((r^2/x0, r*sqrt(1-r^2/x0^2)), color="red", size=50)
down = point((r^2/x0, -r*sqrt(1-r^2/x0^2)), color="red", size=50)
print "The red lengths are equal."
show(circ + lin + p + up + down, axes=False)
︡48dd9fb3-4187-4d0f-b68c-625fa84839a5︡{"stdout":"The red lengths are equal.\n"}︡{"file":{"filename":"/home/user/.sage/temp/project-b3d1725f-1279-45c2-88cc-f7f99fcc7faa/357/tmp_iL9jaR.svg","show":true,"text":null,"uuid":"6c85e5bc-76f5-45d2-9a18-97298ea78b38"},"once":false}︡{"done":true}︡
︠439f0ee4-da6f-4a6d-90a3-18679a9ac3b8i︠
%md
<p>The same is true of spheres:  if $\overline{PA}$ and $\overline{PB}$ are tangent to a sphere at $A$ and $B$ then</p>
$$PA = PB.$$

︡71e8905c-209c-4ae7-8c4b-29f53f821ec0︡{"done":true,"md":"<p>The same is true of spheres:  if $\\overline{PA}$ and $\\overline{PB}$ are tangent to a sphere at $A$ and $B$ then</p>\n$$PA = PB.$$"}
︠8979421c-c726-4dfe-ba7a-37eab5dba7efi︠
x,y=var("x,y")
R=5; r=4; z0 = sqrt(R^2-r^2); x0 = 7
sph = sphere((0,0,0),R, color="yellow")
pla = parametric_plot((x,y,z0),(x,-7,7),(y,-7,7), opacity = 0.5)
lin = line([(r^2/x0,r*sqrt(1-r^2/x0^2),z0),(x0,0,z0),(r^2/x0,-r*sqrt(1-r^2/x0^2),z0)], color="red", thickness=2)
show(sph + pla + lin, frame=False)
︡80322c6e-33d1-4950-9a4b-eff8a41fd53b︡{"file":{"filename":"d0001584-ce29-43ba-90de-6c435f3e957a.sage3d","uuid":"d0001584-ce29-43ba-90de-6c435f3e957a"}}︡{"done":true}︡
︠f34c0a42-e633-4f29-a098-58727aa78ddei︠
%md
<h3>Proof of the distance-to-foci properties</h3>

︡0dfdc1aa-c502-41b6-a69c-07c80e7fa826︡{"done":true,"md":"<h3>Proof of the distance-to-foci properties</h3>"}
︠9236cf0c-09b5-40d6-ac0e-ed90e44d7a9bi︠
%md
**Ellipse:**

In the figure the yellow point is on the ellipse.  The red points are foci.  Each line segment (red or purple) connecting the yellow point to a focus is tangent to the corresponding sphere at the focus because the segment lies in the plane and the plane is tangent to the sphere at the focus.  The spheres are tangent to the cone along the green and purple circles.  The green and purple segments connecting the yellow point to the circles lie in the cone.  The cone is tangent to the spheres, so the segments connecting the yellow point to the circles are tangent to the spheres at the green and purple points where the segments meet the circles.  Therefore, because they are tangent to the same sphere, both green segments have the same length, and both purple segments have the same length.  

Thus the purple length plus the green length is the same as the distance in the figure between the green point on the green circle and the purple point on the purple circle, along the line segment connecting these points in the cone.  The cone, spheres, and circles are rotationally symmetric around the cone's axis, so the length of this line segment is the same no matter where the yellow point is located on the ellipse.  In other words,

*(purple length) + (green length) is constant.*    
︡5d19e0ed-5612-42f7-9102-21826129b99a︡{"done":true,"md":"**Ellipse:**\n\nIn the figure the yellow point is on the ellipse.  The red points are foci.  Each line segment (red or purple) connecting the yellow point to a focus is tangent to the corresponding sphere at the focus because the segment lies in the plane and the plane is tangent to the sphere at the focus.  The spheres are tangent to the cone along the green and purple circles.  The green and purple segments connecting the yellow point to the circles lie in the cone.  The cone is tangent to the spheres, so the segments connecting the yellow point to the circles are tangent to the spheres at the green and purple points where the segments meet the circles.  Therefore, because they are tangent to the same sphere, both green segments have the same length, and both purple segments have the same length.  \n\nThus the purple length plus the green length is the same as the distance in the figure between the green point on the green circle and the purple point on the purple circle, along the line segment connecting these points in the cone.  The cone, spheres, and circles are rotationally symmetric around the cone's axis, so the length of this line segment is the same no matter where the yellow point is located on the ellipse.  In other words,\n\n*(purple length) + (green length) is constant.*"}
︠14b0915a-566f-449e-ba8c-d6d90d798002i︠
# lighten the spheres
dandelin_ell =  sphere(ell.c_sphL, ell.r_sphL, color="blue", opacity=.2) + sphere(ell.c_sphR, ell.r_sphR, color="blue", opacity=.2)  # spheres
dandelin_ell += foci_ell
dandelin_ell += parametric_plot3d((ell.c_cirL[0], ell.r_cirL*sin(t), ell.r_cirL*cos(t)), (t,0,2*pi), color="green", thickness=2)  # left tangent circle
dandelin_ell += parametric_plot3d((ell.c_cirR[0], ell.r_cirR*sin(t), ell.r_cirR*cos(t)), (t,0,2*pi), color="purple", thickness=2)  # right tangent circle
dandelin_ell += cone_ell + plane_ell + ellipse
theta = -.8
dandelin2_ell = dandelin_ell + line([(ell.c_cirL[0],ell.r_cirL*sin(theta),ell.r_cirL*cos(theta)),ell.pt_3d(theta),ell.focL_3d],color="green",thickness=1.5)
dandelin2_ell += line([(ell.c_cirR[0],ell.r_cirR*sin(theta),ell.r_cirR*cos(theta)),ell.pt_3d(theta),ell.focR_3d],color="purple",thickness=1.5)
dandelin2_ell += sphere(ell.pt_3d(theta),0.2,color="yellow")
dandelin2_ell += sphere((ell.c_cirL[0],ell.r_cirL*sin(theta),ell.r_cirL*cos(theta)),0.2,color="green")
dandelin2_ell += sphere((ell.c_cirR[0],ell.r_cirR*sin(theta),ell.r_cirR*cos(theta)),0.2,color="purple")
show(dandelin2_ell.rotateY(.1).rotateX(.2).rotateZ(-.6),frame=False)
︡fe97d450-9124-41df-bd3d-c0fd41a79dd4︡{"file":{"filename":"88a7f243-ded9-4d36-8830-a4f58ffbacbd.sage3d","uuid":"88a7f243-ded9-4d36-8830-a4f58ffbacbd"}}︡{"done":true}︡
︠e623a434-feec-49ae-910e-8bae9759b07bi︠
%md

**Hyperbola:**

The proof is similar to the proof for the ellipse.  In the figure the red points are foci, the yellow point is on the hyperbola, each sphere is tangent to the cone along a green or purple circle.  The green segments connecting the yellow point to the focus and green circle have equal length.  The purple segment connecting yellow point to the other focus has the same length as the green-and-purple segment connecting the yellow point to the purple point on the purple circle.  
The difference in the distances, yellow point-on-hyperbola to foci, equals the length of the segment, green point to purple point, connecting the circles.

This length is just the distance between the circles, measured along a line in the cone, so it doesn't depend on the location of the yellow point. 

Thus the difference beween the distances to the foci does not depend on where the yellow point is located on the hyperbola. 
︡25482321-8eab-4832-a166-0df780df4c1f︡{"done":true,"md":"\n**Hyperbola:**\n\nThe proof is similar to the proof for the ellipse.  In the figure the red points are foci, the yellow point is on the hyperbola, each spheres is tangent to the cone along a green or purple circle.  The green segments connecting the yellow point to the focus and green circle have equal length.  The purple segment connecting yellow point to the other focus has the same length as the green-and-purple segment connecting the yellow point to the purple point on the purple circle.  \nThe difference in the distances, yellow point-on-hyperbola to foci, equals the length of the segment, green point to purple point, connecting the circles.\n\nThis length is just the distance between the circles, measured along a line in the cone, so it doesn't depend on the location of the yellow point. \n\nThus the difference beween the distances to the foci does not depend on where the yellow point is located on the hyperbola."}
︠d427d2f2-81f9-49ee-bf98-0200ece9a971si︠
# lighten the spheres
dandelin_hyp = sphere(hyp.c_sphL, hyp.r_sphL, color="blue", opacity=.2) + sphere(hyp.c_sphR, hyp.r_sphR, color="blue", opacity=.2)
dandelin_hyp += foci_hyp
dandelin_hyp += parametric_plot3d((hyp.c_cirL[0], hyp.r_cirL*sin(t), hyp.r_cirL*cos(t)), (t,0,2*pi), color="green", thickness=2)  # left tangent circle
dandelin_hyp += parametric_plot3d((hyp.c_cirR[0], hyp.r_cirR*sin(t), hyp.r_cirR*cos(t)), (t,0,2*pi), color="purple", thickness=2)  # right tangent circle
dandelin_hyp += cone_hyp + plane_hyp + hyperbola
# point on the left hyperbola
phi = -0.9
dandelin2_hyp = dandelin_hyp + sphere(hyp.ptL_3d(phi),0.5,color="yellow")
# polar angle in z,y plane using z as "x-direction"
(x_pt,y_pt,z_pt)=hyp.ptL_3d(phi)
theta = arctan(y_pt/z_pt)
# corresponding point on left tangent circle
(x_cirL, y_cirL, z_cirL) = (hyp.c_cirL[0], hyp.r_cirL*sin(theta), hyp.r_cirL*cos(theta))
dandelin2_hyp += line([hyp.focL_3d, hyp.ptL_3d(phi), (x_cirL,y_cirL,z_cirL)],thickness=2,color="green")
dandelin2_hyp += sphere((x_cirL,y_cirL,z_cirL), 0.7, color="green")
# corresponding point on right tangent circle
(x_cirR, y_cirR, z_cirR) = (hyp.c_cirR[0], -hyp.r_cirR*sin(theta), -hyp.r_cirR*cos(theta))
dandelin2_hyp += line([hyp.focR_3d, hyp.ptL_3d(phi)],thickness=2,color="purple")
dandelin2_hyp += line([(x_cirL, y_cirL, z_cirL),(x_cirR, y_cirR, z_cirR)],thickness=2,color="purple")
dandelin2_hyp += sphere((x_cirR, y_cirR, z_cirR),0.si
dandelin2_par = dandelin_par
y_par = -10
dandelin2_par += sphere(par.pt_3d(y_par),0.3, color="yellow")  # point on parabola
dandelin2_par += line([par.pt_3d(y_par), par.foc_3d], color="green", thickness=2)  # line to focus
(x_par,y_par,z_par) = par.pt_3d(y_par)  # point on parabola
theta_par = arctan(y_par/z_par)
dandelin2_par += sphere((par.c_cir[0],par.r_cir*sin(theta_par),par.r_cir*cos(theta_par)), 0.3, color = "white") # point on circle
dandelin2_par += line([par.pt_3d(y_par),(par.c_cir[0],par.r_cir*sin(theta_par),par.r_cir*cos(theta_par))], color="green", thickness="2") # line to circle
dandelin2_par += line([par.pt_3d(y_par),par.dir_3d(y_par)], color="blue", thickness=2)  # line to directrix
dandelin2_par += sphere(par.dir_3d(y_par), 0.3, color="blue")  # point on directrix
dandelin2_par += line([par.pt_3d(y_par),(par.c_cir[0],y_par,z_par)], color="black", thickness=2)       #perpendicular to directrix plane
dandelin2_par += sphere((par.c_cir[0],y_par,z_par),0.3, color="black")            # foot of perpendicular
show(dandelin2_par.rotateX(0.22).rotateZ(-0.95),frame=False)
︡832b413b-dd79-42a6-80d4-baaf7e83c44e︡{"file":{"filename":"33209640-8305-46f0-a06d-41918a6f7cbf.sage3d","uuid":"33209640-8305-46f0-a06d-41918a6f7cbf"}}︡{"done":true}︡
︠3015bfeb-35a3-4d0b-866e-505f4d77733bi︠
%md
Let

$\alpha$ = angle between the cone's axis and any cone generator

"green" = the green segment connecting parabola to circle

"black" = black segment, "blue" = segment 

1. "black" is parallel to the axis of the cone
2. "green" lies on a generator of the cone, so 
3. $\alpha = \angle(\text{green, black})$
4. the plane is parallel to one of the cone's tangent planes, so
5. "blue" is parallel to the generator in that tangent plane, so 
6. $\alpha = \angle(\text{blue, black})$

Thus their lengths (blue), (green), (black) satisfy

(blue)$\cos(\alpha)$ = (black) = (green)$\cos(\alpha) \neq 0$

Conclusion:

(blue) = (green)

︡64b6169e-8a2e-44b3-b822-67910e59a27c︡{"done":true,"md":"Let\n\n$\\alpha$ = angle between the cone's axis and any cone generator\n\n\"green\" = the green segment connecting parabola to circle\n\n\"black\" = black segment, \"blue\" = segment \n\n1. \"black\" is parallel to the axis of the cone\n2. \"green\" lies on a generator of the cone, so \n3. $\\alpha = \\angle(\\text{green, black})$\n4. the plane is parallel to one of the cone's tangent planes, so\n5. \"blue\" is parallel to the generator in that tangent plane, so \n6. $\\alpha = \\angle(\\text{blue, black})$\n\nThus their lengths (blue), (green), (black) satisfy\n\n(blue)$\\cos(\\alpha)$ = (black) = (green)$\\cos(\\alpha) \\neq 0$\n\nConclusion:\n\n(blue) = (green)"}
︠8c3b9815-4345-48a4-a45e-5f3ac45a9c1fi︠
%md
A picture showing the blue and black lines translated to the x-z plane so the black line coincides with the cone's axis.  The blue plane is parallel to the tangent plane along the purple generator.
︡22d203d9-cff9-466a-b164-e1819e67f56b︡{"done":true,"md":"A picture showing the blue and black lines translated to the x-z plane so the black line coincides with the cone's axis.  The blue plane is parallel to the tangent plane along the purple generator."}
︠5a01bbf7-ad95-43c9-a8be-5433a6d64d30si︠
gr = cone_par + plane_par
gr += line([(0,0,0),(-20,0,0)],color="black")
gr += line([(par.x_plane(0),0,0),(par.x_plane(13),0,13)], color="blue", thickness=2)
k = 13/(par.x_plane(13)-par.x_plane(0))
gr += line([(-20,0,-20*k),(0,0,0)], color = "purple", thickness=2)
show(gr, frame=False)
︡09569950-eb28-47f5-8064-99d4d5011f75︡{"file":{"filename":"a4b86b88-5b90-4727-a681-52a3adbd85ac.sage3d","uuid":"a4b86b88-5b90-4727-a681-52a3adbd85ac"}}︡{"done":true}︡
︠8e5530d3-e103-48a4-88a4-b52334d4759bs︠
︡2d01cb18-eb15-4847-9460-1cf0c75d12d8︡{"done":true}︡









